@@ -9,23 +9,22 @@ from pathlib import Path
 import coloredlogs
 from pkg_resources import DistributionNotFound, get_distribution
 
-from . import metadata
+from gn2pg import metadata
 
 try:
-    dist_name = "gn2pg_client"
-    __version__ = get_distribution(dist_name).version
+    DIST_NAME = "gn2pg_client"
+    __version__ = get_distribution(DIST_NAME).version
 except DistributionNotFound:  # pragma: no cover
-    __version__ = metadata.version
+    __version__ = metadata.VERSION
 finally:
     del get_distribution, DistributionNotFound
 
-__author__ = metadata.authors_string
-__license__ = metadata.license
-__copyright__ = metadata.copyright
+__author__ = metadata.AUTHORS_STRING
+__license__ = metadata.LICENSE
 
 coloredlogs.DEFAULT_FIELD_STYLES["module"] = {"color": "blue"}
 
-logger = logging.getLogger("transfer_gn")
+logger = logging.getLogger(__name__)
 
 coloredlogs.install(
     level="DEBUG",
