@@ -17,6 +17,8 @@
 BEGIN
 ;
 
+CREATE SCHEMA IF NOT EXISTS gn2pg_import;
+
 DROP FUNCTION IF EXISTS gn2pg_import.fct_c_get_or_insert_basic_af_from_uuid_name (_uuid UUID, _name TEXT)
 ;
 
@@ -232,10 +234,8 @@ DECLARE
     the_additional_data                      JSONB;
     the_meta_validation_date                 TIMESTAMP;
 BEGIN
-    SELECT st_srid(the_geom_local)
-    INTO _local_srid
-    FROM gn_synthese.synthese
-    LIMIT 1;
+    SELECT find_srid('gn_synthese', 'synthese', 'the_geom_local')
+    INTO _local_srid;
     SELECT new.uuid
     INTO the_unique_id_sinp;
     SELECT cast(new.item #>> '{id_perm_grp_sinp}' AS UUID)
@@ -622,11 +622,9 @@ DECLARE
     the_additional_data                      JSONB;
     the_meta_validation_date                 TIMESTAMP;
 BEGIN
-    RAISE NOTICE 'Update synthese_with_cd_nomenclature';
-    SELECT st_srid(the_geom_local)
-    INTO _local_srid
-    FROM gn_synthese.synthese
-    LIMIT 1;
+    RAISE DEBUG 'Update synthese_with_cd_nomenclature';
+    SELECT find_srid('gn_synthese', 'synthese', 'the_geom_local')
+    INTO _local_srid;
     SELECT new.uuid
     INTO the_unique_id_sinp;
     SELECT cast(new.item #>> '{id_perm_grp_sinp}' AS UUID)
@@ -967,7 +965,7 @@ COMMENT ON FUNCTION gn2pg_import.fct_tri_c_delete_data_from_geonature() IS 'Trig
 
 /* BEGIN: SYNTHESE WITH METADATA*/
 
-DROP FUNCTION IF EXISTS gn2pg_import.fct_c_insert_ds_territories(_id_ds INTEGER, _territories JSONB)
+DROP FUNCTION IF EXISTS gn2pg_import.fct_c_insert_ds_territories(_id_ds INTEGER, _territories JSONB);
 
 CREATE OR REPLACE FUNCTION gn2pg_import.fct_c_insert_ds_territories(_id_ds INTEGER, _territories JSONB) RETURNS VOID
     LANGUAGE plpgsql
@@ -976,11 +974,11 @@ $$
 DECLARE
     i RECORD;
 BEGIN
-    RAISE NOTICE '_id_ds %, territories %', _id_ds::INT, _territories;
+    RAISE DEBUG '_id_ds %, territories %', _id_ds::INT, _territories;
 
     FOR i IN (SELECT jsonb_array_elements_text(_territories) item)
         LOOP
-            RAISE NOTICE 'iterritory % %',i, i.item;
+            RAISE DEBUG 'iterritory % %',i, i.item;
             INSERT INTO gn_meta.cor_dataset_territory (id_dataset, id_nomenclature_territory)
             VALUES (_id_ds,
                     ref_nomenclatures.get_id_nomenclature('TERRITOIRE', i.item))
@@ -996,11 +994,11 @@ $$
 DECLARE
     the_id_actor INTEGER;
 BEGIN
-    RAISE NOTICE '_actor_role %', _actor_role;
+    RAISE DEBUG '_actor_role %', _actor_role;
     IF _actor_role ->> 'type_role' = 'organism' THEN
         INSERT INTO utilisateurs.bib_organismes (uuid_organisme, nom_organisme, email_organisme, additional_data)
         VALUES ( (_actor_role ->> 'uuid_actor')::UUID
-               , _actor_role #>> '{name}'
+               , _actor_role #>> '{identity,organism_name}'
                , _actor_role ->> 'email'
                , jsonb_build_object('source', _source, 'module', 'gn2pg'))
         ON CONFLICT (uuid_organisme) DO NOTHING;
@@ -1011,7 +1009,8 @@ BEGIN
     ELSIF _actor_role ->> 'type_role' = 'role' THEN
         INSERT INTO utilisateurs.t_roles (uuid_role, nom_role, prenom_role, email, champs_addi)
         VALUES ( (_actor_role ->> 'uuid_actor')::UUID
-               , _actor_role #>> '{name,name}'
+               , _actor_role #>> '{identity,first_name}'
+               , _actor_role #>> '{identity,last_name}'
                , _actor_role ->> 'email'
                , jsonb_build_object('source', _source, 'module', 'gn2pg'))
         ON CONFLICT (uuid_role) DO NOTHING;
@@ -1051,8 +1050,6 @@ BEGIN
 END
 $$;
 
-ALTER FUNCTION gn2pg_import.fct_c_insert_dataset_actor(INTEGER, JSONB, VARCHAR) OWNER TO orbadmin;
-
 CREATE OR REPLACE FUNCTION gn2pg_import.fct_c_insert_af_actors(_id_af INTEGER, _actor_roles JSONB, _source CHARACTER VARYING) RETURNS VOID
     LANGUAGE plpgsql
 AS
@@ -1060,7 +1057,7 @@ $$
 DECLARE
     i RECORD;
 BEGIN
-    RAISE NOTICE '_id_af %', _id_af::INT;
+    RAISE DEBUG '_id_af %', _id_af::INT;
     FOR i IN (SELECT jsonb_array_elements(_actor_roles) item)
         LOOP
 
@@ -1122,7 +1119,7 @@ BEGIN
     INTO the_af_id
     FROM gn_meta.t_acquisition_frameworks
     WHERE unique_acquisition_framework_id = (_af_data #>> '{uuid}')::UUID;
-    RAISE NOTICE 'the_af_id %', the_af_id;
+    RAISE DEBUG 'the_af_id %', the_af_id;
     PERFORM
         gn2pg_import.fct_c_insert_af_actors(the_af_id, _af_data -> 'actors', _source);
     RETURN the_af_id;
@@ -1138,7 +1135,7 @@ $$
 DECLARE
     the_dataset_id INT;
 BEGIN
-    RAISE NOTICE 'data_type %', _ds_data #>> '{data_type}';
+    RAISE DEBUG 'data_type %', _ds_data #>> '{data_type}';
     INSERT INTO gn_meta.t_datasets ( unique_dataset_id
                                    , id_acquisition_framework
                                    , dataset_name
@@ -1279,11 +1276,9 @@ DECLARE
     the_additional_data                      JSONB;
     the_meta_validation_date                 TIMESTAMP;
 BEGIN
-    RAISE NOTICE 'Update synthese_with_metadata';
-    SELECT st_srid(the_geom_local)
-    INTO _local_srid
-    FROM gn_synthese.synthese
-    LIMIT 1;
+    RAISE DEBUG 'Update synthese_with_metadata';
+    SELECT find_srid('gn_synthese', 'synthese', 'the_geom_local')
+    INTO _local_srid;
     SELECT new.uuid
     INTO the_unique_id_sinp;
     SELECT cast(new.item #>> '{id_perm_grp_sinp}' AS UUID)
@@ -1584,6 +1579,8 @@ $$;
 
 COMMENT ON FUNCTION gn2pg_import.fct_tri_c_upsert_data_to_geonature_with_metadata() IS 'Trigger function to upsert datas from import to synthese';
 
+DROP TRIGGER IF EXISTS tri_c_upsert_data_to_geonature_with_metadata ON gn2pg_import.data_json;
+
 CREATE TRIGGER tri_c_upsert_data_to_geonature_with_metadata
     AFTER INSERT OR UPDATE
     ON gn2pg_import.data_json
@@ -1594,9 +1591,6 @@ EXECUTE PROCEDURE gn2pg_import.fct_tri_c_upsert_data_to_geonature_with_metadata(
 
 /* END: SYNTHESE WITH METADATA */
 
-
-ALTER FUNCTION gn2pg_import.fct_tri_c_upsert_data_to_geonature_with_metadata() OWNER TO orbadmin;
-
 CREATE OR REPLACE FUNCTION gn2pg_import.fct_tri_c_delete_data_from_geonature() RETURNS TRIGGER
     LANGUAGE plpgsql
 AS
@@ -1629,4 +1623,3 @@ EXECUTE PROCEDURE gn2pg_import.fct_tri_c_delete_data_from_geonature()
 
 COMMIT
 ;
-
